# Changes

0.7.0
-----

- make collection document autoload optional
- raise exception on sync without path

0.6.0
-----

- Drop separate config type; support readonly docs instead
- Rename documentdatabases to collections

0.5.0
-----

- DocumentDatabase modification tracking

0.4.0
-----

- cleanup

0.3.0
-----

- refactor layout
- more support for using Paths in init

0.2.2
-----

- add typed stub

0.2.1
-----

- make mypy happy


